@@ -13,13 +13,14 @@ class Plot3DCollection(FDSDataCollection):
         super().__init__(*plot3ds)
         self.times = list(times)
 
-    def filter_by_quantity(self, quantity: Union[str, Quantity]) -> List[Plot3D]:
+    def filter_by_quantity(self, quantity: Union[str, Quantity]):
         """Filters all plot3d data by a specific quantity.
         """
         if type(quantity) != str:
             quantity = quantity.quantity
-        return [x for x in self if any(q.quantity.lower() == quantity.lower() or
-                                       q.label.lower() == quantity.lower() for q in x.quantities)]
+        return Plot3DCollection(x for x in self if any(
+            q.quantity.lower() == quantity.lower() or q.label.lower() == quantity.lower() for q in
+            x.quantities))
 
     def __repr__(self):
         return "Plot3DCollection(" + super(Plot3DCollection, self).__repr__() + ")"
