@@ -1,9 +1,9 @@
 import os
-from copy import deepcopy
+from copy import deepcopy, copy
 
 import numpy as np
 import logging
-from typing import Dict, Collection, Tuple, Union
+from typing import Dict, Collection, Tuple, Union, List
 from typing_extensions import Literal
 
 from fdsreader.utils import Dimension, Quantity, Mesh, Extent
@@ -176,6 +176,19 @@ class Slice(np.lib.mixins.NDArrayOperatorsMixin):
             if "W-VELOCITY" in vector_filenames:
                 self._subslices[mesh].vector_filenames["w"] = vector_filenames["W-VELOCITY"]
 
+        # Iterate over all subslices and remove duplicated ones which will be created when the slice
+        # cuts exactly through two mesh borders. Only required for non-cell-centered slices.
+        if not self.cell_centered:
+            extents_tmp = list()
+            remove_tmp = list()
+            for mesh, sslc in self._subslices.items():
+                if sslc.extent not in extents_tmp:
+                    extents_tmp.append(sslc.extent)
+                else:
+                    remove_tmp.append(mesh)
+            for mesh in remove_tmp:
+                del self._subslices[mesh]
+
         vals = self._subslices.values()
         self.extent = Extent(min(vals, key=lambda e: e.extent.x_start).extent.x_start,
                              max(vals, key=lambda e: e.extent.x_end).extent.x_end,
@@ -233,26 +246,6 @@ class Slice(np.lib.mixins.NDArrayOperatorsMixin):
         else:
             return idx
 
-    def get_nearest_index2(self, dimension: Literal['x', 'y', 'z'], value: float) -> int:
-        index_counter = 0
-        nearest_index = -1
-        nearest_value = np.finfo(np.float32).max
-        for mesh in self._subslices.keys():
-            coords = mesh.coordinates[dimension]
-            idx = np.searchsorted(coords, value, side="left")
-            if (idx == coords.size or np.math.fabs(value - coords[idx - 1]) < np.math.fabs(
-                    value - coords[idx])):
-                if np.math.fabs(coords[idx - 1] - value) < np.math.fabs(nearest_value - value):
-                    nearest_index = idx - 1 + index_counter
-                    nearest_value = coords[idx - 1]
-            else:
-                if np.math.fabs(coords[idx] - value) < np.math.fabs(nearest_value - value):
-                    nearest_index = idx + index_counter
-                    nearest_value = coords[idx]
-            index_counter += coords.size
-
-        return nearest_index
-
     def get_nearest_index(self, dimension: Literal['x', 'y', 'z'], value: float) -> int:
         coords = self.coordinates[dimension]
         idx = np.searchsorted(coords, value, side="left")
@@ -262,6 +255,12 @@ class Slice(np.lib.mixins.NDArrayOperatorsMixin):
         else:
             return idx
 
+    @property
+    def meshes(self) -> List[Mesh]:
+        """Returns a list of all meshes this slice cuts through.
+        """
+        return list(self._subslices.keys())
+
     @property
     def coordinates(self) -> Dict[Literal['x', 'y', 'z'], np.ndarray]:
         coords = {'x': set(), 'y': set(), 'z': set()}
@@ -278,8 +277,10 @@ class Slice(np.lib.mixins.NDArrayOperatorsMixin):
             subslice.clear_cache()
 
     def sort_subslices_cartesian(self):
-        """Returns all subslices sorted in cartesian coordinates.
+        """Returns all subslices sorted in cartesian coordinates (2D-slices only).
         """
+        assert self.type == '2D', "The sort_subslices_cartesian method only works on 2D-slices!"
+
         slices = list(self._subslices.values())
         slices_cart = [[slices[0]]]
         orientation = abs(slices[0].orientation)
@@ -305,10 +306,12 @@ class Slice(np.lib.mixins.NDArrayOperatorsMixin):
         return slices_cart
 
     def to_global(self) -> np.ndarray:
-        """Creates a global numpy ndarray from all subslices.
+        """Creates a global 2D-numpy ndarray from all subslices (2D-slices only).
             Note: This method will only return valid output if evenly sized and spaced meshes were
             used in the simulation. Other cases will require individual custom combination logic.
         """
+        assert self.type == '2D', "The to_global method only works on 2D-slices!"
+
         slices = self.sort_subslices_cartesian()
 
         shape_dim1 = sum([slice_row[0].shape[0] for slice_row in slices])
@@ -334,6 +337,12 @@ class Slice(np.lib.mixins.NDArrayOperatorsMixin):
             dim2_pos = 0
         return slc_array
 
+    @property
+    def type(self) -> Literal['2D', '3D']:
+        if self.orientation == 0:
+            return '3D'
+        return '2D'
+
     def mean(self):
         """Calculates the mean over the whole slice.
 
@@ -387,7 +396,7 @@ class Slice(np.lib.mixins.NDArrayOperatorsMixin):
         return _HANDLED_FUNCTIONS[func](*args, **kwargs)
 
     def __repr__(self):
-        if self.orientation == 0:  # 3D-Slice
+        if self.type == '3D':  # 3D-Slice
             return f"Slice([3D] cell_centered={self.cell_centered}, extent={self.extent}, times=[{self.times[0]:.2f},{self.times[1]:.2f},...,{self.times[-1]:.2f}])"
         else:  # 2D-Slice
             return f"Slice([2D] cell_centered={self.cell_centered}, extent={self.extent}, extent_dirs={self.extent_dirs}, orientation={self.orientation}, times=[{self.times[0]:.2f},{self.times[1]:.2f},...,{self.times[-1]:.2f}])"
